%global _description %{expand:
This Python module contain freestanding implementations of electrostatic
forward models incorporated in LFPy (https://github.com/LFPy/LFPy,
https://LFPy.readthedocs.io).

The aim of the LFPykit module is to provide electrostatic models in a manner
that facilitates forward-model predictions of extracellular potentials and
related measures from multicompartment neuron models, but without explicit
dependencies on neural simulation software such as NEURON
(https://neuron.yale.edu, https://github.com/neuronsimulator/nrn), Arbor
(https://arbor.readthedocs.io, https://github.com/arbor-sim/arbor), or even
LFPy. The LFPykit module can then be more easily incorporated with these
simulators, or in various projects that utilize them such as LFPy
(https://LFPy.rtfd.io, https://github.com/LFPy/LFPy). BMTK
(https://alleninstitute.github.io/bmtk/,
https://github.com/AllenInstitute/bmtk), etc.

Its main functionality is providing class methods that return two-dimensional
linear transformation matrices M between transmembrane currents I of
multicompartment neuron models and some measurement Y given by Y=MI.

The presently incorporated volume conductor models have been incorporated in
LFPy (https://LFPy.rtfd.io, https://github.com/LFPy/LFPy), as described in
various papers and books:

- Linden H, Hagen E, Leski S, Norheim ES, Pettersen KH, Einevoll GT (2014) LFPy:
a tool for biophysical simulation of extracellular potentials generated by
detailed model neurons. Front. Neuroinform. 7:41. doi: 10.3389/fninf.2013.00041

- Hagen E, Næss S, Ness TV and Einevoll GT (2018) Multimodal Modeling of Neural
Network Activity: Computing LFP, ECoG, EEG, and MEG Signals With LFPy 2.0.
Front. Neuroinform. 12:92. doi: 10.3389/fninf.2018.00092

- Ness, T. V., Chintaluri, C., Potworowski, J., Leski, S., Glabska, H., Wójcik,
D. K., et al. (2015). Modelling and analysis of electrical potentials recorded
in microelectrode arrays (MEAs). Neuroinformatics 13:403–426. doi:
10.1007/s12021-015-9265-6

- Nunez and Srinivasan, Oxford University Press, 2006

- Næss S, Chintaluri C, Ness TV, Dale AM, Einevoll GT and Wójcik DK (2017).
Corrected Four-sphere Head Model for EEG Signals. Front. Hum. Neurosci. 11:490.
doi: 10.3389/fnhum.2017.00490}

Name:           python-lfpykit
Version:        0.5.1
Release:        %autorelease
Summary:        Electrostatic models for multicompartment neuron models

License:        GPL-3.0-or-later
URL:            https://pypi.org/pypi/LFPykit
Source0:        %{pypi_source LFPykit}

BuildArch:      noarch

%description %_description

%package -n python3-lfpykit
Summary:        %{summary}
BuildRequires:  python3-devel

%description -n python3-lfpykit %_description

%package doc
Summary:        %{summary}

%description doc
Documentation for %{name}.

%prep
%autosetup -n LFPykit-%{version}

find . -type f -name "*.py" -exec sed -i '/^#![  ]*\/usr\/bin\/env.*$/ d' {} 2>/dev/null ';'

%generate_buildrequires
%pyproject_buildrequires -x tests

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files lfpykit

%check
%pyproject_check_import
%{pytest}

%files -n python3-lfpykit -f %{pyproject_files}
%doc README.md

%files doc
%license LICENSE
%doc examples

%changelog
%autochangelog
